BEGIN;
CREATE TABLE IF NOT EXISTS `accounts` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	varchar(32) NOT NULL DEFAULT 'plain'
,	`password`	text
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `actions` (
	`name`	varchar(255) NOT NULL
,	`enabled`	enum('false','true') NOT NULL DEFAULT 'true'
,	PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `admin_aliases` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`login`	varchar(20) NOT NULL
,	`account_id`	int(10) unsigned NOT NULL
,	`arealname`	varchar(255) NOT NULL
,	`aemail`	varchar(255) NOT NULL
,	`comments`	varchar(255) NOT NULL
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `login` (`login`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `admin_aliases_param` (
	`alias_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`param`	varchar(245) NOT NULL
,	`val`	varchar(5000)
,	PRIMARY KEY (`alias_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apscategories` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`category_name`	varchar(255)
,	`parent_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `parent_id` (`parent_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `APSCatalogUpdates` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`package_name`	varchar(255)
,	`package_version`	varchar(30)
,	`package_release`	varchar(30)
,	`update_name`	varchar(255)
,	`update_version`	varchar(30)
,	`update_release`	varchar(30)
,	`update_vendor`	varchar(255)
,	`update_packager`	varchar(255)
,	`received`	datetime DEFAULT '1970-01-01 00:00:00'
,	`update_type`	enum('patch','upgrade') NOT NULL DEFAULT 'patch'
,	`recommended`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `APSLicenses` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`license_type_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`key_number`	varchar(255) NOT NULL
,	`source`	text
,	`ka_url`	varchar(255) NOT NULL
,	`expiration_date`	date
,	`update_date`	date
,	`personal`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	INDEX `license_type_id` (`license_type_id`)
,	UNIQUE `key_number` (`key_number`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `APSLicenseTypes` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`application_name`	varchar(255) NOT NULL
,	`application_versions`	varchar(255) NOT NULL
,	`application_features`	varchar(255) NOT NULL
,	`description`	varchar(255)
,	`license_type_hash`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `license_type_hash` (`license_type_hash`)
,	UNIQUE `application_name` (`application_name`,`application_versions`,`application_features`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `APSApplicationItems` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`pkg_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`license_type_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`disabled`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `license_type_id` (`license_type_id`,`pkg_id`)
,	INDEX `pkg_id` (`pkg_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `APSClientApplicationItems` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`client_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`app_item_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`instances_limit`	int(10) NOT NULL DEFAULT '-1'
,	`broadcast`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `client_app_item` (`client_id`,`app_item_id`)
,	INDEX `client_id` (`client_id`)
,	INDEX `app_item_id` (`app_item_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apsContexts` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`pleskType`	varchar(255) NOT NULL
,	`pleskId`	int(10) unsigned NOT NULL
,	`ssl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`subscriptionId`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apsContextsApplications` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`apsContextId`	int(10) unsigned NOT NULL
,	`registryApplicationId`	varchar(36) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apsResources` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`registryId`	varchar(36) NOT NULL
,	`pleskType`	varchar(255) NOT NULL
,	`pleskId`	int(10) unsigned NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apsResourcesParameters` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`apsResourceId`	int(10) unsigned NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `apsInstancesParameters` (
	`instanceId`	int(11) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`instanceId`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ApsTokens` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`subscriptionId`	int(10) unsigned NOT NULL
,	`applicationId`	varchar(2000) NOT NULL
,	`instanceId`	int(10) unsigned
,	`token`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `anon_ftp` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`max_conn`	int(10) unsigned
,	`bandwidth`	int(10) unsigned
,	`incoming`	enum('false','true') NOT NULL DEFAULT 'false'
,	`incoming_readable`	enum('false','true') NOT NULL DEFAULT 'false'
,	`incoming_subdirs`	enum('false','true') NOT NULL DEFAULT 'false'
,	`status`	enum('false','true') NOT NULL DEFAULT 'false'
,	`quota`	bigint(20) unsigned DEFAULT '1048576'
,	`display_login`	enum('false','true') NOT NULL DEFAULT 'false'
,	`login_text`	text
,	PRIMARY KEY (`id`)
,	UNIQUE `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `avstatistics` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	enum('summary','viruses','recipients','spam_summary','spam_recipients') NOT NULL DEFAULT 'summary'
,	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`name`	varchar(255) NOT NULL
,	`val`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `date_type` (`type`,`date`)
,	UNIQUE `type` (`type`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BackupExcludeFiles` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`files`	text
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BackupsScheduled` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`obj_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`obj_type`	enum('server','reseller','client','domain') NOT NULL
,	`repository`	enum('local','ext','local-and-ext') NOT NULL DEFAULT 'local'
,	`last`	datetime
,	`period`	int(10) unsigned NOT NULL DEFAULT '0'
,	`active`	enum('false','true') NOT NULL
,	`processed`	enum('false','true') NOT NULL
,	`rotation`	int(11) NOT NULL DEFAULT '0'
,	`prefix`	varchar(255)
,	`email`	varchar(255)
,	`split_size`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`suspend`	enum('false','true') NOT NULL DEFAULT 'false'
,	`with_content`	enum('false','true') NOT NULL DEFAULT 'true'
,	`backup_day`	int(10) unsigned NOT NULL DEFAULT '0'
,	`backup_time`	varchar(8) NOT NULL DEFAULT '00:00:00'
,	`content_type`	enum('backup_content_all_at_domain','backup_content_vhost_only','backup_content_mail_only') NOT NULL DEFAULT 'backup_content_all_at_domain'
,	`full_backup_period`	int(11) unsigned NOT NULL DEFAULT '0'
,	`mssql_native_backup`	int(1) NOT NULL DEFAULT '1'
,	`backupExcludeFilesId`	int(10) unsigned
,	`backupExcludeLogs`	int(1) NOT NULL DEFAULT '0'
,	`remoteStorage`	varchar(255)
,	`exclude_mail`	int(1) NOT NULL DEFAULT '0'
,	`exclude_user_files`	int(1) NOT NULL DEFAULT '0'
,	`exclude_user_databases`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BackupsSettings` (
	`id`	int(10) unsigned
,	`type`	enum('domain','client','server') NOT NULL DEFAULT 'domain'
,	`param`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	UNIQUE `id` (`id`,`type`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `badmailfrom` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`domain`	varchar(255) NOT NULL
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	PRIMARY KEY (`id`)
,	INDEX `domain` (`domain`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `certificates` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`csr`	blob
,	`pvt_key`	blob
,	`cert`	blob
,	`cert_file`	varchar(255) NOT NULL DEFAULT ''
,	`ca_cert`	blob
,	`ca_file`	varchar(255) NOT NULL DEFAULT ''
,	`name`	varchar(255) NOT NULL DEFAULT ''
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `cl_param` (
	`cl_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`param`	varchar(245) NOT NULL
,	`val`	varchar(5000)
,	PRIMARY KEY (`cl_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `CliCallsStat` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`util`	varchar(255) NOT NULL
,	`command`	varchar(255) NOT NULL
,	`lastExecutionDateTime`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`count`	bigint(20) unsigned NOT NULL DEFAULT '1'
,	PRIMARY KEY (`id`)
,	UNIQUE `utilCommand` (`command`,`util`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `clients` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`cr_date`	date
,	`cname`	varchar(255)
,	`pname`	varchar(255) NOT NULL
,	`login`	varchar(255) NOT NULL
,	`account_id`	int(10) unsigned NOT NULL
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`phone`	varchar(255)
,	`fax`	varchar(255)
,	`email`	varchar(255)
,	`address`	varchar(255)
,	`city`	varchar(255)
,	`state`	varchar(255)
,	`pcode`	varchar(10)
,	`country`	varchar(2)
,	`locale`	varchar(17) NOT NULL DEFAULT 'en-US'
,	`description`	varchar(255)
,	`limits_id`	int(10) unsigned DEFAULT '0'
,	`params_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`perm_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`pool_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`logo_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`tmpl_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`sapp_pool_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`ownership`	enum('false','true') NOT NULL DEFAULT 'true'
,	`guid`	varchar(36) NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'
,	`parent_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`type`	enum('admin','reseller','client') NOT NULL DEFAULT 'client'
,	`overuse`	enum('false','true') NOT NULL DEFAULT 'false'
,	`vendor_id`	int(10) unsigned
,	`external_id`	varchar(255)
,	`passwd`	varchar(20) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `pname` (`pname`)
,	UNIQUE `login` (`login`)
,	INDEX `vendor_id` (`vendor_id`)
,	INDEX `type` (`type`)
,	INDEX `parent_id` (`parent_id`)
,	INDEX `account_id` (`account_id`)
,	INDEX `limits_id` (`limits_id`)
,	INDEX `params_id` (`params_id`)
,	INDEX `perm_id` (`perm_id`)
,	INDEX `pool_id` (`pool_id`)
,	INDEX `logo_id` (`logo_id`)
,	INDEX `tmpl_id` (`tmpl_id`)
,	INDEX `sapp_pool_id` (`sapp_pool_id`)
,	UNIQUE `guid` (`guid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `clients` (`type`,`login`,`pname`,`passwd`,`account_id`,`cr_date`) VALUES ('admin','admin','Administrator','','0',now());

CREATE TABLE IF NOT EXISTS `ClientsTraffic` (
	`cl_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`http_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`http_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`ftp_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`ftp_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`smtp_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`smtp_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`pop3_imap_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`pop3_imap_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`cl_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Configurations` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`file`	blob
,	`version`	varchar(255) NOT NULL
,	`objectType`	varchar(255) NOT NULL
,	`objectId`	int(10) unsigned
,	`status`	enum('error','generation','ok') NOT NULL DEFAULT 'error'
,	`active`	enum('false','true') NOT NULL DEFAULT 'true'
,	`description`	blob
,	`errorFile`	blob
,	PRIMARY KEY (`id`)
,	INDEX `objectTypeAndId_index` (`objectType`,`objectId`)
,	INDEX `status` (`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `cp_access` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	enum('allow','deny') NOT NULL DEFAULT 'allow'
,	`netaddr`	varchar(39) NOT NULL
,	`netmask`	varchar(15) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `custom_buttons` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`sort_key`	int(10) unsigned NOT NULL DEFAULT '100'
,	`level`	int(10) unsigned NOT NULL DEFAULT '0'
,	`level_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`place`	enum('domain','domain-properties','client','reseller','reseller-settings','admin','admin-settings','navigation') NOT NULL DEFAULT 'domain'
,	`text`	varchar(255)
,	`url`	varchar(255)
,	`conhelp`	text
,	`options`	int(10) unsigned NOT NULL DEFAULT '0'
,	`file`	varchar(245) NOT NULL
,	`plan_item_name`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `data_bases` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(64) NOT NULL
,	`type`	enum('mysql','postgresql','mssql') NOT NULL DEFAULT 'mysql'
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`db_server_id`	int(10) unsigned NOT NULL
,	`default_user_id`	int(10) unsigned
,	`external_id`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `name_and_db_server_id` (`name`,`db_server_id`)
,	INDEX `dom_id` (`dom_id`)
,	INDEX `db_server_id` (`db_server_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DatabaseCustomHosts` (
	`id`	int(10) unsigned NOT NULL
,	`host`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DatabaseServers` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`host`	varchar(255) NOT NULL
,	`port`	int(10) unsigned
,	`type`	enum('mysql','postgresql','mssql') NOT NULL DEFAULT 'mysql'
,	`server_version`	char(255)
,	`admin_login`	char(255) NOT NULL
,	`admin_password`	char(255) NOT NULL
,	`parameters_id`	int(10) unsigned
,	`last_error`	enum('no_error','connection_failed','permission_denied','other_error','credentials_not_set') NOT NULL DEFAULT 'no_error'
,	`fork`	varchar(20)
,	PRIMARY KEY (`id`)
,	INDEX `host_port` (`host`,`port`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `db_users` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`login`	varchar(128) NOT NULL
,	`account_id`	int(10) unsigned NOT NULL
,	`db_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`status`	enum('normal','orphaned') NOT NULL DEFAULT 'normal'
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`db_server_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`passwd`	varchar(16) NOT NULL
,	`external_id`	varchar(255)
,	`role`	varchar(255) NOT NULL DEFAULT 'readWrite'
,	PRIMARY KEY (`id`)
,	UNIQUE `db_server_id` (`db_server_id`,`db_id`,`login`)
,	INDEX `account_id` (`account_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DatabaseUserRemoteAccessRules` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`ipAddress`	varchar(39) NOT NULL
,	`mask`	varchar(15) NOT NULL
,	`type`	enum('allow','deny') NOT NULL
,	`databaseUserId`	int(10) unsigned NOT NULL
,	`firewallRuleId`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `disk_usage` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`httpdocs`	bigint(20) unsigned DEFAULT '0'
,	`httpsdocs`	bigint(20) unsigned DEFAULT '0'
,	`subdomains`	bigint(20) unsigned DEFAULT '0'
,	`web_users`	bigint(20) unsigned DEFAULT '0'
,	`anonftp`	bigint(20) unsigned DEFAULT '0'
,	`logs`	bigint(20) unsigned DEFAULT '0'
,	`mysql_dbases`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`mssql_dbases`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`pgsql_dbases`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`mailboxes`	bigint(20) unsigned DEFAULT '0'
,	`maillists`	bigint(20) unsigned DEFAULT '0'
,	`domaindumps`	bigint(20) unsigned DEFAULT '0'
,	`www_root`	bigint(20) unsigned DEFAULT '0'
,	`dbases`	bigint(20) unsigned DEFAULT '0'
,	`configs`	bigint(20) unsigned DEFAULT '0'
,	`chroot`	bigint(20) unsigned DEFAULT '0'
,	PRIMARY KEY (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `dns_recs` (
	`time_stamp`	timestamp DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`dns_zone_id`	int(10) unsigned
,	`type`	enum('NS','A','AAAA','CNAME','MX','PTR','TXT','AXFR','SRV','DS','CAA','TLSA','HTTPS','master','none') NOT NULL DEFAULT 'A'
,	`host`	varchar(255) NOT NULL
,	`displayHost`	varchar(255) NOT NULL
,	`val`	text NOT NULL
,	`displayVal`	text NOT NULL
,	`opt`	varchar(255) NOT NULL DEFAULT ''
,	`external_id`	varchar(255)
,	`ttl`	int(11) unsigned
,	PRIMARY KEY (`id`)
,	INDEX `dns_zone_id` (`dns_zone_id`)
,	INDEX `type` (`type`)
,	INDEX `host` (`host`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `dns_recs_t` (
	`time_stamp`	timestamp DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	enum('NS','A','AAAA','CNAME','MX','PTR','SOA','TXT','AXFR','SRV','CAA','TLSA','none') NOT NULL DEFAULT 'A'
,	`host`	varchar(255) NOT NULL
,	`displayHost`	varchar(255) NOT NULL
,	`val`	text NOT NULL
,	`displayVal`	text NOT NULL
,	`opt`	varchar(255) NOT NULL DEFAULT ''
,	`uid`	varchar(255)
,	`ttl`	int(11) unsigned
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('1','NS','<domain>.','<domain>.','ns1.<domain>.','ns1.<domain>.','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('2','A','ns1.<domain>.','ns1.<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('3','AAAA','ns1.<domain>.','ns1.<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('4','NS','<domain>.','<domain>.','ns2.<domain>.','ns2.<domain>.','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('5','A','ns2.<domain>.','ns2.<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('6','AAAA','ns2.<domain>.','ns2.<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('7','A','<domain>.','<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('8','AAAA','<domain>.','<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('9','A','webmail.<domain>.','webmail.<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('10','AAAA','webmail.<domain>.','webmail.<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('13','MX','<domain>.','<domain>.','mail.<domain>.','mail.<domain>.','10');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('14','A','mail.<domain>.','mail.<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('15','AAAA','mail.<domain>.','mail.<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('16','A','ipv4.<domain>.','ipv4.<domain>.','<ip>','<ip>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('17','AAAA','ipv6.<domain>.','ipv6.<domain>.','<ipv6>','<ipv6>','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('18','CNAME','ftp.<domain>.','ftp.<domain>.','<domain>.','<domain>.','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('19','TXT','<domain>.','<domain>.','v=spf1 +a +mx +a:<hostname> -all','v=spf1 +a +mx +a:<hostname> -all','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('20','TXT','_dmarc.<domain>.','_dmarc.<domain>.','v=DMARC1; p=quarantine; adkim=s; aspf=s','v=DMARC1; p=quarantine; adkim=s; aspf=s','');
REPLACE INTO `dns_recs_t` (`id`,`type`,`host`,`displayHost`,`val`,`displayVal`,`opt`) VALUES ('21','CNAME','www.<domain>.','www.<domain>.','<domain>.','<domain>.','');

CREATE TABLE IF NOT EXISTS `dns_refs` (
	`uid`	varchar(255) NOT NULL
,	`zoneId`	int(10) unsigned NOT NULL
,	`zoneRecordId`	int(10) unsigned
,	`templateRecordId`	int(10) unsigned
,	`status`	enum('syn','mod','del') NOT NULL DEFAULT 'syn'
,	PRIMARY KEY (`uid`)
,	INDEX `zoneId` (`zoneId`)
,	INDEX `zoneRecordId` (`zoneRecordId`)
,	INDEX `templateRecordId` (`templateRecordId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `dns_zone` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`displayName`	varchar(255) NOT NULL
,	`email`	varchar(255)
,	`status`	int(10) unsigned NOT NULL DEFAULT '0'
,	`type`	enum('slave','master') NOT NULL DEFAULT 'master'
,	`ttl`	int(10) unsigned NOT NULL DEFAULT '86400'
,	`ttl_unit`	int(10) unsigned NOT NULL DEFAULT '1'
,	`refresh`	int(10) unsigned NOT NULL DEFAULT '10800'
,	`refresh_unit`	int(10) unsigned NOT NULL DEFAULT '1'
,	`retry`	int(10) unsigned NOT NULL DEFAULT '3600'
,	`retry_unit`	int(10) unsigned NOT NULL DEFAULT '1'
,	`expire`	int(10) unsigned NOT NULL DEFAULT '604800'
,	`expire_unit`	int(10) unsigned NOT NULL DEFAULT '1'
,	`minimum`	int(10) unsigned NOT NULL DEFAULT '10800'
,	`minimum_unit`	int(10) unsigned NOT NULL DEFAULT '1'
,	`serial_format`	enum('UNIXTIMESTAMP','YYYYMMDDNN') NOT NULL DEFAULT 'UNIXTIMESTAMP'
,	`serial`	varchar(12) NOT NULL DEFAULT '0'
,	`external_id`	varchar(255)
,	`syncSoa`	enum('true','false','skip') NOT NULL DEFAULT 'skip'
,	`syncRecords`	enum('true','false','skip') NOT NULL DEFAULT 'skip'
,	`rnameType`	enum('owner','domain','external') NOT NULL DEFAULT 'owner'
,	`mname`	varchar(255) NOT NULL DEFAULT ''
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `dom_param` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`param`	varchar(245) NOT NULL
,	`val`	varchar(5000)
,	PRIMARY KEY (`dom_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `domain_aliases` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`displayName`	varchar(255) NOT NULL
,	`dns_zone_id`	int(10) unsigned
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`mail`	enum('true','false') NOT NULL DEFAULT 'false'
,	`web`	enum('true','false') NOT NULL DEFAULT 'false'
,	`dns`	enum('true','false') NOT NULL DEFAULT 'false'
,	`tomcat`	enum('true','false') NOT NULL DEFAULT 'false'
,	`seoRedirect`	enum('false','true') NOT NULL DEFAULT 'false'
,	`external_id`	varchar(255)
,	`icpStatus`	int(1) NOT NULL DEFAULT '0'
,	`icpPermit`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
,	INDEX `displayName` (`displayName`)
,	INDEX `dom_id` (`dom_id`)
,	INDEX `dns_zone_id` (`dns_zone_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainAliasesParameters` (
	`aliasId`	int(10) unsigned NOT NULL
,	`param`	varchar(255) NOT NULL
,	`val`	varchar(5000)
,	PRIMARY KEY (`aliasId`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainKeys` (
	`domainServiceId`	int(10) unsigned NOT NULL
,	`selector`	varchar(255) NOT NULL
,	`privateKey`	blob
,	`publicKey`	blob
,	PRIMARY KEY (`domainServiceId`,`selector`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainOutgoingMessagesPeaks` (
	`domainId`	int(10) unsigned NOT NULL
,	`beginDate`	datetime NOT NULL
,	`endDate`	datetime
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`domainId`,`beginDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainOutgoingMessagesStats` (
	`domainId`	int(10) unsigned NOT NULL
,	`collectDate`	datetime NOT NULL
,	`limitValue`	bigint(20) NOT NULL DEFAULT '-1'
,	`passed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`passed_fixed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected_verified`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`domainId`,`collectDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `domains` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`cr_date`	date
,	`name`	varchar(255) NOT NULL
,	`displayName`	varchar(255) NOT NULL
,	`dns_zone_id`	int(10) unsigned
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`htype`	enum('none','vrt_hst','std_fwd','frm_fwd') NOT NULL DEFAULT 'none'
,	`real_size`	bigint(20) unsigned DEFAULT '0'
,	`cl_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`cert_rep_id`	int(10) unsigned DEFAULT '0'
,	`limits_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`params_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`guid`	varchar(255) NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'
,	`overuse`	enum('false','true') NOT NULL DEFAULT 'false'
,	`vendor_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`webspace_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`parentDomainId`	int(10) unsigned NOT NULL DEFAULT '0'
,	`webspace_status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`permissions_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`external_id`	varchar(255)
,	`adminDescription`	varchar(255)
,	`resellerDescription`	varchar(255)
,	`description`	varchar(255)
,	`gl_filter`	enum('on','off') NOT NULL DEFAULT 'on'
,	`icpStatus`	int(1) NOT NULL DEFAULT '0'
,	`icpPermit`	varchar(255)
,	`monthlyTraffic`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
,	INDEX `displayName` (`displayName`)
,	INDEX `cl_id` (`cl_id`)
,	INDEX `dns_zone_id` (`dns_zone_id`)
,	INDEX `vendor_id` (`vendor_id`)
,	INDEX `webspace_id` (`webspace_id`)
,	INDEX `parentDomainId` (`parentDomainId`)
,	INDEX `permissions_id` (`permissions_id`)
,	INDEX `external_id` (`external_id`)
,	INDEX `cert_rep_id` (`cert_rep_id`)
,	INDEX `limits_id` (`limits_id`)
,	INDEX `params_id` (`params_id`)
,	UNIQUE `guid` (`guid`)
,	INDEX `monthlyTraffic` (`monthlyTraffic`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainServices` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`type`	enum('mail','tomcat','maillists','web')
,	`status`	bigint(20) NOT NULL DEFAULT '0'
,	`parameters_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`ipCollectionId`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `dom_id` (`dom_id`)
,	INDEX `parameters_id` (`parameters_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DomainsTraffic` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`http_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`http_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`ftp_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`ftp_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`smtp_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`smtp_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`pop3_imap_in`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`pop3_imap_out`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`dom_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `dsn` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`name`	varchar(255) NOT NULL
,	`driver`	varchar(255) NOT NULL
,	`description`	varchar(255)
,	`configured`	enum('false','true') NOT NULL DEFAULT 'false'
,	`cstring`	text
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`,`serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `DynamicIpSecurity` (
	`dom_id`	int(10) unsigned NOT NULL
,	`isDenyByConcurrentRequests`	int(11) NOT NULL DEFAULT '0'
,	`maxConcurrentRequests`	int(10) unsigned NOT NULL DEFAULT '5'
,	`isDenyByRequestRate`	int(11) NOT NULL DEFAULT '0'
,	`maxRequests`	int(10) unsigned NOT NULL DEFAULT '20'
,	`requestInterval`	int(10) unsigned NOT NULL DEFAULT '200'
,	PRIMARY KEY (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `EmailActivations` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`hash`	varchar(255) NOT NULL
,	`created`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`clientId`	int(11) unsigned NOT NULL DEFAULT '0'
,	`smbUserId`	int(11) unsigned NOT NULL DEFAULT '0'
,	`adminAliasId`	int(11) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `hash` (`hash`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `event_handlers` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`priority`	int(10) unsigned NOT NULL DEFAULT '0'
,	`user`	varchar(255) NOT NULL DEFAULT 'nobody'
,	`command`	text
,	`action_name`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `action_name` (`action_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `exp_event` (
	`event_time`	timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
,	`id`	bigint(10) unsigned NOT NULL auto_increment
,	`source`	enum('pa','plesk')
,	`event_type`	enum('started','stopped','created','updated','deleted','status_changed','terminated','flushed','installed','uninstalled','siteapp_added','siteapp_removed','expired','exceeded','guid_changed') NOT NULL DEFAULT 'started'
,	`obj_class`	varchar(255) NOT NULL DEFAULT 'license'
,	`obj_id`	varchar(255) NOT NULL
,	`host`	varchar(255) NOT NULL
,	`user`	varchar(255) NOT NULL
,	`flushed`	enum('true','false') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	INDEX `source` (`source`,`event_type`)
,	INDEX `source_2` (`source`,`event_type`,`obj_class`)
,	INDEX `source_3` (`source`,`event_time`,`event_type`,`obj_class`)
,	INDEX `flushed` (`flushed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ApiRpcCallsStat` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`Version`	varchar(7) NOT NULL
,	`Operator`	varchar(50) NOT NULL
,	`Command`	varchar(50) NOT NULL
,	`Session`	varchar(8) NOT NULL DEFAULT '0'
,	`FilterName`	varchar(50) NOT NULL DEFAULT '0'
,	`GroupOperation`	int(10) NOT NULL DEFAULT '0'
,	`LastExecutionDate`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`Count`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `LogItem` (`Version`,`Operator`,`Command`,`Session`,`FilterName`,`GroupOperation`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `externalWebmails` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255)
,	`url`	varchar(255)
,	`enabled`	int(10) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Fail2BanIps` (
	`jail`	varchar(20) NOT NULL
,	`address`	varchar(240) NOT NULL
,	PRIMARY KEY (`jail`,`address`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `forwarding` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`redirect`	varchar(255)
,	`http_code`	int(10) unsigned NOT NULL DEFAULT '301'
,	`ssl`	enum('true','false') NOT NULL DEFAULT 'false'
,	`sslRedirect`	enum('true','false') NOT NULL DEFAULT 'false'
,	`certificate_id`	int(10) unsigned DEFAULT '0'
,	PRIMARY KEY (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ftp_users` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`sys_user_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`permission`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`external_id`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `sys_user_id` (`sys_user_id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `GL_remote_domains` (
	`serviceNodeId`	int(11) NOT NULL DEFAULT '1'
,	`domain`	varchar(255) NOT NULL
,	`type`	enum('black','white') NOT NULL DEFAULT 'black'
,	PRIMARY KEY (`serviceNodeId`,`domain`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*facebook.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*google.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*yahoo.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*parallels.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*plesk.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*mail.ru','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*yandex.ru','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*rambler.ru','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*.office365.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*.outlook.office.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*.outlook.com','white');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('dynamic|static|ppp|dyn-ip|dial-up','black');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('dsl|broadband|hsd','black');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*[0-9][0-9].[0-9][0-9].[0-9][0-9]*','black');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*[0-9][0-9][0-9].[0-9][0-9][0-9].[0-9[0-9]][0-9]*','black');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*[0-9][0-9]-[0-9][0-9]-[0-9][0-9]*','black');
REPLACE INTO `GL_remote_domains` (`domain`,`type`) VALUES ('*[0-9][0-9][0-9]-[0-9][0-9][0-9]-[0-9][0-9][0-9]*','black');

CREATE TABLE IF NOT EXISTS `GL_settings` (
	`serviceNodeId`	int(11) NOT NULL DEFAULT '1'
,	`param`	varchar(255) NOT NULL
,	`value`	varchar(255) NOT NULL
,	PRIMARY KEY (`serviceNodeId`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `GL_settings` (`param`,`value`) VALUES ('greyInterval','5');
REPLACE INTO `GL_settings` (`param`,`value`) VALUES ('expireInterval','51840');
REPLACE INTO `GL_settings` (`param`,`value`) VALUES ('penaltyInterval','2');
REPLACE INTO `GL_settings` (`param`,`value`) VALUES ('penaltyEnabled','false');
REPLACE INTO `GL_settings` (`param`,`value`) VALUES ('enabled','false');

CREATE TABLE IF NOT EXISTS `hosting` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`sys_user_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`real_traffic`	bigint(20) unsigned DEFAULT '0'
,	`ssi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`ssi_html`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php_isapi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php_handler_id`	varchar(255)
,	`cgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`perl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`python`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp_dot_net`	enum('false','true') NOT NULL DEFAULT 'false'
,	`managed_runtime_version`	varchar(255) NOT NULL DEFAULT ''
,	`ssl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`webstat`	varchar(20) NOT NULL DEFAULT 'none'
,	`at_domains`	enum('false','true') NOT NULL DEFAULT 'false'
,	`write_modify`	varchar(255)
,	`www_root`	text NOT NULL
,	`webdeploy`	enum('false','true') NOT NULL DEFAULT 'false'
,	`certificate_id`	int(10) unsigned DEFAULT '0'
,	`traffic_bandwidth`	int(11) DEFAULT '-1'
,	`max_connection`	int(11) DEFAULT '-1'
,	`fastcgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`same_ssl`	enum('false','true') NOT NULL DEFAULT 'true'
,	`sslRedirect`	enum('true','false') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `hotlink_friends` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL
,	`friend_dom`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `hotlink_prot` (
	`dom_id`	int(10) unsigned NOT NULL
,	`enabled`	enum('false','true') NOT NULL DEFAULT 'false'
,	`extensions`	varchar(255) NOT NULL
,	PRIMARY KEY (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `IisAppPoolsPolicy` (
	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`mode`	enum('shared','dedicated','mixed') NOT NULL DEFAULT 'mixed'
,	PRIMARY KEY (`serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `IisAppPoolsPolicy` (`serviceNodeId`,`mode`) VALUES ('1','mixed');

CREATE TABLE IF NOT EXISTS `IisAppPools` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`ownerType`	enum('client','domain') NOT NULL DEFAULT 'client'
,	`ownerId`	int(10) unsigned NOT NULL
,	`identity`	varchar(20) NOT NULL
,	`isStarted`	int(11) NOT NULL DEFAULT '1'
,	`cpuLimit`	int(11) NOT NULL DEFAULT '-1'
,	`cpuLimitAction`	enum('NoAction','KillW3wp','Throttle','ThrottleUnderLoad') NOT NULL DEFAULT 'NoAction'
,	`cpuLimitInterval`	int(10) unsigned NOT NULL DEFAULT '5'
,	`maxProcesses`	int(10) unsigned NOT NULL DEFAULT '1'
,	`idleTimeout`	int(10) unsigned NOT NULL DEFAULT '5'
,	`idleTimeoutAction`	enum('Terminate','Suspend') NOT NULL DEFAULT 'Terminate'
,	`recyclingByTime`	int(11) NOT NULL DEFAULT '1740'
,	`recyclingByRequests`	int(11) NOT NULL DEFAULT '-1'
,	`recyclingByVirtualMemory`	bigint(11) NOT NULL DEFAULT '-1'
,	`recyclingByPrivateMemory`	bigint(11) NOT NULL DEFAULT '-1'
,	`managedPipelineMode`	enum('Classic','Integrated') NOT NULL DEFAULT 'Integrated'
,	`externalId`	varchar(255)
,	`enable32bitAppOnWin64`	int(1) NOT NULL DEFAULT '1'
,	`loadUserProfile`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `ownerId` (`serviceNodeId`,`ownerType`,`ownerId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `IisAppPoolDomains` (
	`domainId`	int(10) unsigned NOT NULL
,	`poolId`	int(10) unsigned NOT NULL
,	PRIMARY KEY (`domainId`)
,	INDEX `poolId` (`poolId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `IP_Addresses` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`ip_address`	varchar(39) NOT NULL
,	`mask`	varchar(15) NOT NULL DEFAULT '255.255.255.0'
,	`iface`	varchar(255) NOT NULL
,	`ssl_certificate_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`default_domain_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`ftps`	enum('false','true') NOT NULL DEFAULT 'false'
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`public_ip_address`	varchar(39)
,	`main`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `ip_address` (`ip_address`)
,	INDEX `ssl_certificate_id` (`ssl_certificate_id`)
,	INDEX `default_domain_id` (`default_domain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ip_pool` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`ip_address_id`	int(10) unsigned NOT NULL
,	`type`	enum('shared','exclusive') NOT NULL DEFAULT 'shared'
,	PRIMARY KEY (`id`,`ip_address_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `IpCollections` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `IpAddressesCollections` (
	`ipCollectionId`	int(10) unsigned NOT NULL
,	`ipAddressId`	int(10) unsigned NOT NULL
,	PRIMARY KEY (`ipCollectionId`,`ipAddressId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `key_history` (
	`register_date`	timestamp DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`plesk_key_id`	varchar(63)
,	`name`	varchar(255)
,	`filename`	varchar(255)
,	`update_disabled`	enum('false','true') NOT NULL DEFAULT 'false'
,	`options`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `key_history_params` (
	`key_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`param`	varchar(63) NOT NULL
,	`val`	varchar(255)
,	PRIMARY KEY (`key_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Limits` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`limit_name`	varchar(255) NOT NULL
,	`value`	bigint(20)
,	PRIMARY KEY (`id`,`limit_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `LimitsReservation` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`collectionRef`	varchar(128) NOT NULL
,	`limitName`	varchar(255) NOT NULL
,	`value`	bigint(20)
,	`expiration`	datetime NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `collection` (`collectionRef`,`limitName`)
,	INDEX `expiration` (`expiration`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `locales` (
	`id`	varchar(17) NOT NULL
,	`active`	enum('false','true') NOT NULL DEFAULT 'true'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `locales` (`id`,`active`) VALUES ('en-US','true');

CREATE TABLE IF NOT EXISTS `log_actions` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`date`	datetime(3)
,	`ip_address`	varchar(39) NOT NULL
,	`user`	varchar(255) NOT NULL
,	`object_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`action_name`	varchar(255) NOT NULL
,	`owner_id`	int(10) unsigned
,	PRIMARY KEY (`id`)
,	INDEX `action_name` (`action_name`)
,	INDEX `date` (`date`)
,	INDEX `owner_id_date` (`owner_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `log_components` (
	`action_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`component`	varchar(255) NOT NULL
,	`old_value`	varchar(255) NOT NULL
,	`new_value`	varchar(255) NOT NULL
,	PRIMARY KEY (`action_id`,`component`)
,	INDEX `action_id` (`action_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `log_rotation` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`period_type`	enum('by_time','by_size') NOT NULL DEFAULT 'by_time'
,	`period`	varchar(50)
,	`max_number_of_logfiles`	bigint(20) unsigned DEFAULT '0'
,	`compress_enable`	enum('false','true') NOT NULL DEFAULT 'false'
,	`email`	varchar(255)
,	`turned_on`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Logos` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255)
,	`fake`	varchar(255)
,	`url`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `longtasks` (
	`startTime`	timestamp DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	varchar(255) NOT NULL
,	`status`	varchar(255) NOT NULL DEFAULT 'not_started'
,	`statusProcessed`	int(10) unsigned NOT NULL DEFAULT '0'
,	`context`	varchar(255)
,	`progressStatus`	varchar(255) NOT NULL DEFAULT 'queue'
,	`progressParams`	blob
,	`progressMax`	int(10) unsigned NOT NULL DEFAULT '1'
,	`progressValue`	int(10) unsigned NOT NULL DEFAULT '0'
,	`finishTime`	timestamp
,	`pid`	int(10) unsigned NOT NULL DEFAULT '0'
,	`externalId`	varchar(255)
,	`updateTime`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `longtaskparams` (
	`task_id`	int(10) unsigned NOT NULL
,	`param`	varchar(255) NOT NULL
,	`val`	mediumtext
,	PRIMARY KEY (`task_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mail` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`userId`	int(10) unsigned
,	`mail_name`	varchar(245) NOT NULL
,	`postbox`	enum('false','true') NOT NULL DEFAULT 'false'
,	`delivery`	enum('false','true') NOT NULL DEFAULT 'true'
,	`account_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`mail_group`	enum('false','true') NOT NULL DEFAULT 'false'
,	`autoresponder`	enum('false','true') NOT NULL DEFAULT 'false'
,	`mbox_quota`	bigint(20) NOT NULL DEFAULT '-1'
,	`description`	varchar(255)
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`disk_usage`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`perm_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`spamfilter`	enum('false','true') NOT NULL DEFAULT 'true'
,	`virusfilter`	enum('none','incoming','outgoing','any') NOT NULL DEFAULT 'none'
,	`externalEmail`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `dom_id` (`dom_id`,`mail_name`)
,	INDEX `account_id` (`account_id`)
,	INDEX `perm_id` (`perm_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mail_aliases` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`mn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`alias`	varchar(245) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `mn_id` (`mn_id`,`alias`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mail_redir` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`mn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`address`	varchar(245) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mail_resp` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`mn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`resp_name`	varchar(245) NOT NULL
,	`keystr`	varchar(255)
,	`key_where`	enum('subj','body','no') NOT NULL DEFAULT 'no'
,	`subject`	varchar(255)
,	`reply_to`	varchar(255)
,	`text`	mediumtext
,	`resp_on`	enum('false','true') NOT NULL DEFAULT 'false'
,	`ans_freq`	int(11) DEFAULT '10'
,	`mem_limit`	int(11) DEFAULT '1000'
,	`content_type`	varchar(245) NOT NULL DEFAULT 'text/plain'
,	`charset`	varchar(245) NOT NULL DEFAULT 'UTF-8'
,	`endDate`	date
,	PRIMARY KEY (`id`)
,	INDEX `mn_id_resp_name` (`mn_id`,`resp_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `MailLists` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`status`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `MailMessagesStat` (
	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`sent`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `MailOutgoingMessagesPeaks` (
	`mailId`	int(10) unsigned NOT NULL
,	`beginDate`	datetime NOT NULL
,	`endDate`	datetime
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`mailId`,`beginDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `MailOutgoingMessagesStats` (
	`mailId`	int(10) unsigned NOT NULL
,	`collectDate`	datetime NOT NULL
,	`limitValue`	bigint(20) NOT NULL DEFAULT '-1'
,	`passed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`passed_fixed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected_verified`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`mailId`,`collectDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mass_mail` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`from_email`	varchar(255) NOT NULL
,	`to_admin`	enum('false','true') NOT NULL DEFAULT 'false'
,	`to_resellers`	enum('false','true') NOT NULL DEFAULT 'false'
,	`to_resellers_mode`	enum('all','select','except') NOT NULL DEFAULT 'all'
,	`to_clients`	enum('false','true') NOT NULL DEFAULT 'false'
,	`to_clients_mode`	enum('all','select','except') NOT NULL DEFAULT 'all'
,	`to_domains`	enum('false','true') NOT NULL DEFAULT 'false'
,	`to_domains_mode`	enum('all','select','except') NOT NULL DEFAULT 'all'
,	`subject`	varchar(255) NOT NULL
,	`body`	text NOT NULL
,	`cdate`	date
,	PRIMARY KEY (`id`)
,	INDEX `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mass_mail_clients` (
	`mm_id`	int(10) unsigned NOT NULL
,	`cl_id`	int(10) unsigned NOT NULL
,	UNIQUE `mm_cl` (`mm_id`,`cl_id`)
,	INDEX `mm_id` (`mm_id`)
,	INDEX `cl_id` (`cl_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `mass_mail_domains` (
	`mm_id`	int(10) unsigned NOT NULL
,	`dom_id`	int(10) unsigned NOT NULL
,	UNIQUE `mm_dom` (`mm_id`,`dom_id`)
,	INDEX `mm_id` (`mm_id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `misc` (
	`param`	varchar(255) NOT NULL
,	`val`	varchar(2000)
,	PRIMARY KEY (`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `misc` (`param`,`val`) VALUES ('actionlog_rot_num_periods','30');
REPLACE INTO `misc` (`param`,`val`) VALUES ('actionlog_rot_num_records','3000');
REPLACE INTO `misc` (`param`,`val`) VALUES ('actionlog_rot_period','day');
REPLACE INTO `misc` (`param`,`val`) VALUES ('actionlog_rot_type','by_period');
REPLACE INTO `misc` (`param`,`val`) VALUES ('allow_short_pop3_names','disabled');
REPLACE INTO `misc` (`param`,`val`) VALUES ('def_skin_id','1');
REPLACE INTO `misc` (`param`,`val`) VALUES ('dns_recursion','localnets');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_domaindumps','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_logs','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_mailboxes','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_maillists','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_remote_databases','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('login_timeout','30');
REPLACE INTO `misc` (`param`,`val`) VALUES ('multiply_login','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('restart_apache_gracefully','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('secure_passwords','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('admin_skin_id','1');
REPLACE INTO `misc` (`param`,`val`) VALUES ('include_databases','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('size_count_type','block');
REPLACE INTO `misc` (`param`,`val`) VALUES ('admin_password_encrypted','true');
REPLACE INTO `misc` (`param`,`val`) VALUES ('soa_serial_format','YYYYMMDDNN');
REPLACE INTO `misc` (`param`,`val`) VALUES ('max_bu_proc_number','10');
REPLACE INTO `misc` (`param`,`val`) VALUES ('backup_suggest_encrypt_backups','list_only');
REPLACE INTO `misc` (`param`,`val`) VALUES ('last_admin_login_date','1970-01-01 00:00:00');
REPLACE INTO `misc` (`param`,`val`) VALUES ('last_login_date','1970-01-01 00:00:00');

CREATE TABLE IF NOT EXISTS `mn_param` (
	`mn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`param`	varchar(245) NOT NULL
,	`val`	varchar(255)
,	PRIMARY KEY (`mn_id`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Modules` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`packname`	varchar(255) NOT NULL
,	`display_name`	varchar(255) NOT NULL
,	`version`	varchar(30) NOT NULL
,	`release`	int(10) unsigned NOT NULL
,	`description`	varchar(255)
,	`icon`	varchar(255) NOT NULL
,	`plesk_max_version`	varchar(30)
,	`status`	enum('true','false') NOT NULL DEFAULT 'true'
,	`hidden`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ModuleSettings` (
	`module_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(5000)
,	PRIMARY KEY (`module_id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Notes` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`text`	text NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Notifications` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`code`	varchar(255) NOT NULL
,	`send2admin`	varchar(1) NOT NULL
,	`send2reseller`	varchar(1)
,	`send2client`	varchar(1) NOT NULL
,	`send2email`	varchar(1) NOT NULL
,	`email`	varchar(255) NOT NULL
,	`subj`	varchar(255)
,	`note_id`	int(10) unsigned
,	PRIMARY KEY (`id`)
,	INDEX `note_id` (`note_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PackageUpdateLocks` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`serviceNodeId`	int(10) unsigned NOT NULL
,	`package`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `serviceNodeId` (`serviceNodeId`)
,	UNIQUE `package` (`serviceNodeId`,`package`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PackageUpdateNotifications` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`serviceNodeId`	int(10) unsigned NOT NULL
,	`eventDate`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`notificationSent`	int(1) NOT NULL DEFAULT '0'
,	`data`	mediumtext
,	PRIMARY KEY (`id`)
,	INDEX `serviceNodeId` (`serviceNodeId`)
,	UNIQUE `eventDate` (`serviceNodeId`,`eventDate`)
,	INDEX `notificationSent` (`notificationSent`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PanelNotificationMessages` (
	`createdAt`	timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`clientId`	int(10) unsigned
,	`adminAliasId`	int(10) unsigned
,	`isRead`	int(1) NOT NULL DEFAULT '0'
,	`isFavorite`	int(1) NOT NULL DEFAULT '0'
,	`subject`	varchar(255) NOT NULL
,	`message`	text
,	`actionText`	varchar(255) NOT NULL
,	`actionLink`	varchar(255) NOT NULL
,	`category`	varchar(255) NOT NULL
,	`area`	varchar(255) NOT NULL
,	`context`	varchar(255) NOT NULL
,	`contextIconUrl`	varchar(255) NOT NULL
,	`isViewed`	int(1) NOT NULL DEFAULT '0'
,	`code`	varchar(255) NOT NULL
,	`openInNewTab`	int(1) NOT NULL DEFAULT '0'
,	`messageKey`	varchar(255)
,	`isPromotion`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `clientId` (`clientId`)
,	INDEX `adminAliasId` (`adminAliasId`)
,	INDEX `isRead` (`isRead`)
,	INDEX `isFavorite` (`isFavorite`)
,	INDEX `category` (`category`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PanelNotificationTemplateSettings` (
	`code`	varchar(255) NOT NULL
,	`sendToAdmin`	int(1) NOT NULL DEFAULT '0'
,	UNIQUE `code` (`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Parameters` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`parameter`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`id`,`parameter`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `password_secrets` (
	`secret`	varchar(255) NOT NULL
,	`type`	int(10) unsigned NOT NULL
,	`id`	int(10) unsigned NOT NULL
,	`created`	datetime NOT NULL
,	PRIMARY KEY (`secret`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `pd_users` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`login`	varchar(32) NOT NULL
,	`account_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`pd_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `pd_id` (`pd_id`,`login`)
,	INDEX `account_id` (`account_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Permissions` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`permission`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`id`,`permission`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PhpSettingsCustom` (
	`id`	int(10) unsigned NOT NULL
,	`value`	text
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PlansSubscriptions` (
	`subscription_id`	int(10) unsigned NOT NULL
,	`plan_id`	int(10) unsigned NOT NULL
,	`quantity`	int(10) unsigned NOT NULL DEFAULT '1'
,	PRIMARY KEY (`subscription_id`,`plan_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ScheduledTasks` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`hash`	varchar(255) NOT NULL
,	`serviceNodeId`	int(10) unsigned NOT NULL
,	`sysUserId`	int(10) unsigned
,	`sysUserLogin`	varchar(255)
,	`isActive`	int(1) NOT NULL DEFAULT '0'
,	`type`	enum('exec','http','php') NOT NULL DEFAULT 'exec'
,	`phpHandlerId`	varchar(255)
,	`command`	text NOT NULL
,	`arguments`	text
,	`description`	text
,	`notify`	enum('ignore','errors','always') NOT NULL DEFAULT 'ignore'
,	`emailType`	enum('default','owner','custom') NOT NULL DEFAULT 'owner'
,	`email`	text
,	`minute`	varchar(255) NOT NULL
,	`hour`	varchar(255) NOT NULL
,	`dayOfMonth`	varchar(255) NOT NULL
,	`month`	varchar(255) NOT NULL
,	`dayOfWeek`	varchar(255) NOT NULL
,	`period`	int(11) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `serviceNodeId` (`serviceNodeId`)
,	INDEX `sysUserId` (`sysUserId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SchemaVersions` (
	`version`	varchar(14) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `SchemaVersions` (`version`) VALUES ('20240716140447');

CREATE TABLE IF NOT EXISTS `SecretKeys` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`clientId`	int(10) unsigned
,	`hash`	varchar(255) NOT NULL
,	`description`	varchar(255) NOT NULL
,	`lookupId`	varchar(8) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `clientId` (`clientId`)
,	INDEX `lookupId` (`lookupId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SecretKeysIpAddresses` (
	`keyId`	int(10) unsigned NOT NULL
,	`ipAddress`	varchar(39) NOT NULL
,	PRIMARY KEY (`ipAddress`,`keyId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Subscriptions` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`object_id`	int(10) unsigned NOT NULL
,	`object_type`	enum('client','domain') NOT NULL
,	`locked`	enum('false','true') NOT NULL DEFAULT 'false'
,	`synchronized`	enum('false','true') NOT NULL DEFAULT 'true'
,	`custom`	enum('false','true') NOT NULL DEFAULT 'false'
,	`uuid`	varchar(36)
,	`external_id`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `object_id_and_type` (`object_id`,`object_type`)
,	UNIQUE `uuid` (`uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SubscriptionOutgoingMessagesPeaks` (
	`subscriptionId`	int(10) unsigned NOT NULL
,	`beginDate`	datetime NOT NULL
,	`endDate`	datetime
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`subscriptionId`,`beginDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SubscriptionOutgoingMessagesStats` (
	`subscriptionId`	int(10) unsigned NOT NULL
,	`collectDate`	datetime NOT NULL
,	`limitValue`	bigint(20) NOT NULL DEFAULT '-1'
,	`passed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`passed_fixed`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`rejected_verified`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`subscriptionId`,`collectDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SubscriptionProperties` (
	`subscription_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255) NOT NULL
,	PRIMARY KEY (`subscription_id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PhpSettings` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`noteId`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PhpSettingsParameters` (
	`id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`value`	text
,	PRIMARY KEY (`id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PlanItems` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`classname`	varchar(255) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`isVisible`	int(10) unsigned NOT NULL DEFAULT '1'
,	`applicableToSubscription`	int(10) unsigned NOT NULL DEFAULT '0'
,	`applicableToEmail`	int(10) unsigned NOT NULL DEFAULT '0'
,	`applicableToSite`	int(10) unsigned NOT NULL DEFAULT '0'
,	`uuid`	varchar(36) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
,	UNIQUE `uuid` (`uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PlanItemProperties` (
	`plan_item_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255) NOT NULL
,	PRIMARY KEY (`plan_item_id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PleskStats` (
	`param`	varchar(255) NOT NULL
,	`value`	blob
,	PRIMARY KEY (`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `protected_dirs` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`non_ssl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`ssl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`realm`	varchar(255)
,	`path`	varchar(245) NOT NULL
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`dom_type`	enum('domain','subdomain') NOT NULL DEFAULT 'domain'
,	`cgi_bin`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `dom_id` (`dom_id`,`path`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `report` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	int(10) unsigned NOT NULL DEFAULT '0'
,	`user_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`user_type`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255)
,	`is_default`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `report_auto` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`report_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`auto`	int(10) unsigned NOT NULL DEFAULT '0'
,	`last`	datetime
,	`recipient`	int(10) unsigned NOT NULL DEFAULT '0'
,	`email`	varchar(254) NOT NULL
,	`client`	int(10) unsigned DEFAULT '0'
,	`domain`	int(10) unsigned DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `report_id` (`report_id`)
,	INDEX `client` (`client`)
,	INDEX `domain` (`domain`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `report_section` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`report_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`type`	enum('none','summary','full') NOT NULL DEFAULT 'summary'
,	PRIMARY KEY (`id`)
,	INDEX `report_id` (`report_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `CertificateRepositories` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Repository` (
	`rep_id`	int(10) unsigned NOT NULL
,	`component_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`rep_id`,`component_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `resp_attach` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`rn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`filename`	varchar(245) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `rn_id` (`rn_id`,`filename`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `resp_forward` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`rn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`address`	varchar(245) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `resp_freq` (
	`time_resp`	timestamp DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`rn_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`email`	varchar(245) NOT NULL
,	`num`	int(11) DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `rn_id` (`rn_id`,`email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `RestrictedDomains` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('1','facebook.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('2','google.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('3','youtube.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('4','yahoo.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('5','baidu.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('6','wikipedia.org');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('7','live.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('8','amazon.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('9','qq.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('10','twitter.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('11','taobao.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('12','blogspot.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('13','google.co.in');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('14','linkedin.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('15','yahoo.co.jp');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('16','sina.com.cn');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('17','msn.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('18','yandex.ru');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('19','ebay.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('20','google.co.jp');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('21','google.de');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('22','wordpress.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('23','bing.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('24','google.com.hk');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('25','vk.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('26','google.co.uk');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('27','google.fr');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('28','babylon.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('29','163.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('30','weibo.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('31','microsoft.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('32','tumblr.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('33','googleusercontent.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('34','mail.ru');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('35','pinterest.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('36','apple.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('37','google.com.br');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('38','soso.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('39','paypal.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('40','google.ru');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('41','google.es');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('42','google.it');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('43','xhamster.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('44','tmall.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('45','fc2.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('46','blogger.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('47','imdb.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('48','craigslist.org');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('49','xvideos.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('50','ask.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('51','sohu.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('52','hao123.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('53','conduit.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('54','bbc.co.uk');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('55','go.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('56','amazon.co.jp');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('57','google.com.mx');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('58','odnoklassniki.ru');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('59','google.ca');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('60','youku.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('61','livejasmin.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('62','amazon.de');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('63','adobe.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('64','flickr.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('65','avg.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('66','ifeng.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('67','t.co');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('68','pornhub.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('69','aol.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('70','rakuten.co.jp');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('71','cnn.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('72','thepiratebay.sx');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('73','mywebsearch.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('74','ebay.de');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('75','amazon.co.uk');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('76','adf.ly');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('77','alibaba.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('78','espn.go.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('79','blogspot.in');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('80','google.com.tr');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('81','redtube.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('82','google.co.id');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('83','instagram.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('84','huffingtonpost.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('85','alipay.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('86','about.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('87','stackoverflow.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('88','sogou.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('89','google.com.au');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('90','livedoor.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('91','360buy.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('92','ebay.co.uk');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('93','netflix.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('94','dailymotion.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('95','imgur.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('96','zedo.com');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('97','google.pl');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('98','uol.com.br');
REPLACE INTO `RestrictedDomains` (`id`,`name`) VALUES ('99','360.cn');

CREATE TABLE IF NOT EXISTS `SBConfig` (
	`param_name`	varchar(255)
,	`param_value`	varchar(255)
,	UNIQUE `param_name` (`param_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SBResellers` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`client_id`	int(10) unsigned NOT NULL
,	`sb_client_login`	varchar(255) NOT NULL
,	`sb_reseller_id`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `client_id` (`client_id`)
,	UNIQUE `sb_client_login` (`sb_client_login`)
,	UNIQUE `sb_reseller_id` (`sb_reseller_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `secret_keys` (
	`key_id`	varchar(255) NOT NULL
,	`ip_address`	varchar(39) NOT NULL
,	`description`	varchar(255) NOT NULL
,	`client_id`	int(10) unsigned
,	`lookup_id`	varchar(255)
,	INDEX `key_id` (`key_id`)
,	INDEX `client_id` (`client_id`)
,	INDEX `lookup_id` (`lookup_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ServiceNodeCache` (
	`serviceNodeId`	int(10) unsigned NOT NULL
,	`pathId`	varchar(255) NOT NULL
,	`path`	text
,	`cache`	text
,	PRIMARY KEY (`serviceNodeId`,`pathId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ServiceNodeCertificates` (
	`serviceNodeId`	int(10) unsigned NOT NULL
,	`certificateId`	int(10) unsigned NOT NULL
,	`certFile`	varchar(255)
,	`caFile`	varchar(255)
,	PRIMARY KEY (`serviceNodeId`,`certificateId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ServiceNodeEnvironment` (
	`serviceNodeId`	int(10) unsigned NOT NULL
,	`section`	varchar(255) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	text
,	PRIMARY KEY (`serviceNodeId`,`section`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `ServiceNodeConfiguration` (
	`serviceNodeId`	int(10) unsigned NOT NULL
,	`section`	varchar(255) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	text
,	PRIMARY KEY (`serviceNodeId`,`section`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','poplock_time','20');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','relay','auth');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','disable_pop_auth','1');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','disable_smtp_auth','0');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_mbox_limit','10');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_domain_limit','50');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_subscription_limit','100');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_report_period','P1W');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_notification_period','PT1H');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_filter_enabled','false');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_messages_enable_sendmail','true');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','outgoing_email_mode','domain-ip');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','spamfilter_enabled','true');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','spamfilter_use_mailuser_prefs','true');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','mailServer','spamfilter_max_children','5');
REPLACE INTO `ServiceNodeConfiguration` (`serviceNodeId`,`section`,`name`,`value`) VALUES ('1','dnsConnector','plesk','true');

CREATE TABLE IF NOT EXISTS `ServiceNodes` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`ipAddress`	varchar(255) NOT NULL DEFAULT 'local'
,	`description`	varchar(255) NOT NULL
,	`type`	varchar(255) NOT NULL DEFAULT 'plesk'
,	`accessKey`	text
,	`externalId`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `ipAddress` (`ipAddress`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `ServiceNodes` (`id`,`ipAddress`,`description`) VALUES ('1','local','Local');

CREATE TABLE IF NOT EXISTS `sessions` (
	`sess_id`	varchar(33) NOT NULL
,	`type`	smallint(5) unsigned NOT NULL DEFAULT '0'
,	`login`	varchar(255)
,	`ip_address`	varchar(39)
,	`ip_dual_stack`	varchar(39)
,	`login_time`	int(10) unsigned
,	`modified`	int(10) unsigned
,	`lifetime`	int(10) unsigned
,	PRIMARY KEY (`sess_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SessionContexts` (
	`contextId`	varchar(255) NOT NULL
,	`sessionId`	varchar(33)
,	`data`	mediumtext
,	PRIMARY KEY (`contextId`)
,	INDEX `sessionId` (`sessionId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SiteAppsHitsStat` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`count`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `SitePagesStat` (
	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`hits`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	PRIMARY KEY (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Skins` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`place`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `name` (`name`)
,	INDEX `place` (`place`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `Skins` (`id`,`name`,`place`) VALUES ('1','Default','default');

CREATE TABLE IF NOT EXISTS `smtp_poplocks` (
	`ip_address`	varchar(39) NOT NULL
,	`ip_mask`	int(10) unsigned NOT NULL DEFAULT '32'
,	`lock_time`	datetime
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	INDEX `ip_address` (`ip_address`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `spamfilter` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`username`	varchar(128) NOT NULL
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	`preferences`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `spamfilter_username_serviceNodeId` (`username`,`serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `spamfilter` (`id`,`username`,`preferences`) VALUES ('1','*@*','true');

CREATE TABLE IF NOT EXISTS `spamfilter_preferences` (
	`prefid`	int(10) unsigned NOT NULL auto_increment
,	`spamfilter_id`	int(10) unsigned NOT NULL
,	`preference`	varchar(30) NOT NULL
,	`value`	varchar(255) NOT NULL
,	PRIMARY KEY (`prefid`)
,	INDEX `spamfilter_id` (`spamfilter_id`,`preference`,`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `spamfilter_preferences` (`spamfilter_id`,`preference`,`value`) VALUES ('1','required_score','7.00');
REPLACE INTO `spamfilter_preferences` (`spamfilter_id`,`preference`,`value`) VALUES ('1','rewrite_header','subject *****SPAM*****');

CREATE TABLE IF NOT EXISTS `stat` (
	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`date`	date NOT NULL DEFAULT '1970-01-01'
,	`transfer`	bigint(20) unsigned
,	PRIMARY KEY (`dom_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `subdomains` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`name`	varchar(255) NOT NULL
,	`displayName`	varchar(255) NOT NULL
,	`sys_user_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`ssi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php_handler_type`	enum('cgi','fastcgi','module','isapi') NOT NULL DEFAULT 'module'
,	`cgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`perl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`python`	enum('false','true') NOT NULL DEFAULT 'false'
,	`coldfusion`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp_dot_net`	enum('false','true') NOT NULL DEFAULT 'false'
,	`ssl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`www_root`	varchar(255) NOT NULL DEFAULT 'httpdocs'
,	`maintenance_mode`	enum('false','true') NOT NULL DEFAULT 'false'
,	`certificate_id`	int(10) unsigned DEFAULT '0'
,	`fastcgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`same_ssl`	enum('false','true') NOT NULL DEFAULT 'true'
,	PRIMARY KEY (`id`)
,	UNIQUE `dom_id` (`dom_id`,`name`)
,	INDEX `dom_id_displayName` (`dom_id`,`displayName`)
,	INDEX `sys_user_id` (`sys_user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `suspend_handler_history` (
	`dom_id`	int(10) unsigned NOT NULL
,	`session_id`	varchar(255)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `sys_users` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '0'
,	`login`	varchar(32) NOT NULL
,	`account_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`home`	varchar(255) NOT NULL
,	`shell`	varchar(255) NOT NULL
,	`quota`	bigint(20) unsigned NOT NULL DEFAULT '0'
,	`mapped_to`	int(10) unsigned
,	PRIMARY KEY (`id`)
,	UNIQUE `login` (`serviceNodeId`,`login`)
,	INDEX `account_id` (`account_id`)
,	INDEX `mapped_to` (`mapped_to`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Templates` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`owner_id`	int(10) unsigned NOT NULL
,	`type`	enum('reseller','client','domain','domain_addon') NOT NULL
,	`uuid`	varchar(36) NOT NULL
,	`external_id`	varchar(255)
,	`note_id`	int(10) unsigned
,	PRIMARY KEY (`id`)
,	INDEX `owner_id` (`owner_id`)
,	UNIQUE `uuid` (`uuid`)
,	INDEX `note_id` (`note_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `TmplData` (
	`tmpl_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`element`	varchar(255) NOT NULL
,	`value`	varchar(255) NOT NULL
,	PRIMARY KEY (`tmpl_id`,`element`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `TraceFailedRequestsProviderAreas` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`providerId`	int(10) unsigned NOT NULL
,	`name`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`providerId`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `TraceFailedRequestsProviders` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`ruleId`	int(10) unsigned NOT NULL
,	`name`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`ruleId`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `TraceFailedRequestsRules` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`domainId`	int(10) unsigned NOT NULL
,	`statusCodes`	varchar(255) NOT NULL
,	`stopDate`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`isEnabled`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `isEnabled` (`isEnabled`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `upgrade_history` (
	`upgrade_date`	datetime NOT NULL DEFAULT '1970-01-01 00:00:00'
,	`version_info`	varchar(50)
,	`db_version`	varchar(50)
,	`os`	varchar(255)
,	`mu`	varchar(255)
,	`update_ticket`	varchar(255) NOT NULL DEFAULT ''
,	PRIMARY KEY (`upgrade_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `UserSettings` (
	`userId`	int(10) unsigned NOT NULL
,	`param`	varchar(255) NOT NULL
,	`val`	varchar(5000)
,	PRIMARY KEY (`userId`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `web_users` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`sys_user_id`	int(10) unsigned NOT NULL DEFAULT '0'
,	`ssi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`ssi_html`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php`	enum('false','true') NOT NULL DEFAULT 'false'
,	`php_isapi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`cgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	`perl`	enum('false','true') NOT NULL DEFAULT 'false'
,	`python`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp`	enum('false','true') NOT NULL DEFAULT 'false'
,	`asp_dot_net`	enum('false','true') NOT NULL DEFAULT 'false'
,	`managed_runtime_version`	varchar(255) NOT NULL DEFAULT '1.1'
,	`write_modify`	varchar(255)
,	`fastcgi`	enum('false','true') NOT NULL DEFAULT 'false'
,	PRIMARY KEY (`id`)
,	UNIQUE `sys_user_id` (`sys_user_id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `PersistentCache` (
	`key`	varchar(128) NOT NULL
,	`uid`	varchar(32) NOT NULL
,	`expire`	timestamp NOT NULL
,	`events`	varchar(255) NOT NULL
,	PRIMARY KEY (`key`,`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BackendCache` (
	`key`	varchar(128) NOT NULL
,	`data`	text NOT NULL
,	PRIMARY KEY (`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_users` (
	`id`	int(11) NOT NULL auto_increment
,	`login`	varchar(255)
,	`password`	varchar(255)
,	`contactName`	varchar(255)
,	`email`	varchar(255)
,	`companyName`	varchar(255)
,	`phone`	varchar(255)
,	`fax`	varchar(255)
,	`address`	text
,	`city`	varchar(255)
,	`state`	varchar(255)
,	`zip`	varchar(255)
,	`country`	varchar(255)
,	`creationDate`	varchar(25) NOT NULL
,	`isBuiltIn`	int(11) DEFAULT '0'
,	`isDomainAdmin`	int(11) DEFAULT '0'
,	`roleId`	int(11) NOT NULL
,	`uuid`	varchar(36) NOT NULL
,	`isLocked`	int(11) DEFAULT '0'
,	`externalId`	varchar(255)
,	`ownerId`	int(11)
,	`additionalInfo`	text
,	`imNumber`	varchar(255)
,	`imType`	int(11)
,	`isLegacyUser`	int(11) DEFAULT '0'
,	`subscriptionDomainId`	int(11) DEFAULT '0'
,	`locale`	varchar(17)
,	`externalEmail`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `uuid` (`uuid`)
,	UNIQUE `login` (`login`)
,	INDEX `subscriptionDomainId_idx` (`subscriptionDomainId`)
,	INDEX `isBuiltIn_idx` (`isBuiltIn`)
,	INDEX `ownerId_idx` (`ownerId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_users` (`id`,`login`,`password`,`contactName`,`email`,`companyName`,`phone`,`fax`,`address`,`city`,`state`,`zip`,`country`,`creationDate`,`isBuiltIn`,`isDomainAdmin`,`roleId`,`uuid`,`isLocked`,`externalId`) VALUES ('1','admin','','admin','','','','','','','','','','','1','0','1','','0','');

CREATE TABLE IF NOT EXISTS `smb_locales` (
	`id`	int(11) NOT NULL auto_increment
,	`code`	varchar(255)
,	`title`	varchar(255)
,	`isActive`	int(11) DEFAULT '1'
,	PRIMARY KEY (`id`)
,	UNIQUE `code` (`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_locales` (`id`,`code`,`title`,`isActive`) VALUES ('1','en-US','ENGLISH (United States)','1');

CREATE TABLE IF NOT EXISTS `smb_componentUpdates` (
	`id`	int(11) NOT NULL auto_increment
,	`componentName`	varchar(255)
,	`version`	varchar(255)
,	`build`	varchar(255)
,	`shown`	int(11) DEFAULT '0'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsPackages` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`version`	varchar(255)
,	`release`	varchar(255)
,	`vendor`	varchar(255)
,	`vendorHomePage`	varchar(255)
,	`packager`	varchar(255)
,	`packagerHomePage`	varchar(255)
,	`cacheId`	varchar(255) NOT NULL
,	`installed`	varchar(26)
,	`isUploaded`	int(11) DEFAULT '0'
,	`isVisible`	int(11) DEFAULT '0'
,	`globalSettingsNotSet`	int(11) DEFAULT '0'
,	`registryUid`	varchar(36)
,	PRIMARY KEY (`id`)
,	UNIQUE `cacheId` (`cacheId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsContexts` (
	`id`	int(11) NOT NULL auto_increment
,	`contextType`	int(11) DEFAULT '0'
,	`packageId`	int(11) NOT NULL
,	`requirementContextClass`	varchar(255)
,	`requirementContextId`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsSettings` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	`contextId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsMetas` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255) NOT NULL
,	`serviceId`	varchar(255)
,	`xpath`	varchar(255)
,	`class`	varchar(255)
,	`contextId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsInstances` (
	`id`	int(11) NOT NULL auto_increment
,	`parentContextId`	int(11) NOT NULL
,	`contextId`	int(11) NOT NULL
,	`metaId`	int(11) NOT NULL
,	`uuid`	varchar(255)
,	`registryResourceId`	varchar(36)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsResources` (
	`id`	int(11) NOT NULL auto_increment
,	`class`	varchar(255) NOT NULL
,	`contextId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsResourceParameters` (
	`id`	int(11) NOT NULL auto_increment
,	`resourceId`	int(11) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsProvisions` (
	`id`	int(11) NOT NULL auto_increment
,	`class`	varchar(255) NOT NULL
,	`contextId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsProvisionEnvironments` (
	`id`	int(11) NOT NULL auto_increment
,	`provisionId`	int(11) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsPackageUpdates` (
	`id`	int(11) NOT NULL auto_increment
,	`packageId`	int(11) NOT NULL
,	`updatePackageId`	int(11)
,	`catalog`	varchar(255)
,	`version`	varchar(255)
,	`release`	varchar(255)
,	`packager`	varchar(255)
,	`severity`	varchar(255)
,	`level`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsInstanceErrors` (
	`id`	int(11) NOT NULL auto_increment
,	`instanceId`	int(11) NOT NULL
,	`creationDate`	varchar(25) NOT NULL
,	`text`	text
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_roles` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255)
,	`isBuiltIn`	int(11) DEFAULT '0'
,	`ownerId`	int(11)
,	`isActivationRequired`	int(1) NOT NULL DEFAULT '0'
,	PRIMARY KEY (`id`)
,	INDEX `ownerId_idx` (`ownerId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_productUpgrades` (
	`id`	int(11) NOT NULL auto_increment
,	`releaseId`	varchar(255)
,	`version`	varchar(255)
,	`description`	varchar(255)
,	`shown`	int(11) DEFAULT '0'
,	`codename`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsCategories` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255)
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsPackagesCategories` (
	`id`	int(11) NOT NULL auto_increment
,	`categoryId`	int(11)
,	`packageId`	int(11)
,	PRIMARY KEY (`id`)
,	INDEX `categoryId_idx` (`categoryId`)
,	INDEX `packageId_idx` (`packageId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsBundleFilters` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	enum('white','black') NOT NULL DEFAULT 'black'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_apsBundleFilterItems` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`filterId`	int(10) unsigned NOT NULL DEFAULT '0'
,	`propertyName`	varchar(255)
,	`propertyValue`	varchar(255)
,	PRIMARY KEY (`id`)
,	INDEX `filterId_idx` (`filterId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_generalPermissions` (
	`id`	int(11) NOT NULL auto_increment
,	`code`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('1','userManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('2','webSitesAndDomainsManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('3','logRotationManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('4','anonymousFtpManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('5','scheduledTasksManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('6','spamfilterManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('7','antivirusManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('8','databasesManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('9','backupRestoreManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('10','browseStats');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('11','applicationsManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('12','sitebuilderManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('13','filesManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('14','ftpAccountsManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('15','dnsManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('17','mailManagement');
REPLACE INTO `smb_generalPermissions` (`id`,`code`) VALUES ('18','mailListsManagement');

CREATE TABLE IF NOT EXISTS `smb_roleGeneralPermissions` (
	`id`	int(11) NOT NULL auto_increment
,	`roleId`	int(11) NOT NULL
,	`generalPermissionId`	int(11) NOT NULL
,	`isAllowed`	int(11)
,	PRIMARY KEY (`id`)
,	INDEX `roleId_idx` (`roleId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('101','1','1','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('102','1','2','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('103','1','3','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('104','1','4','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('105','1','5','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('106','1','6','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('107','1','7','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('108','1','8','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('109','1','9','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('110','1','10','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('111','1','11','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('112','1','12','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('113','1','13','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('114','1','14','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('115','1','15','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('117','1','17','1');
REPLACE INTO `smb_roleGeneralPermissions` (`id`,`roleId`,`generalPermissionId`,`isAllowed`) VALUES ('118','1','18','1');

CREATE TABLE IF NOT EXISTS `smb_serviceProviders` (
	`id`	int(11) NOT NULL auto_increment
,	`classname`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_serviceProviders` (`id`,`classname`) VALUES ('1','Smb_Service_Provider_Aps');

CREATE TABLE IF NOT EXISTS `smb_serviceInstances` (
	`id`	int(11) NOT NULL auto_increment
,	`description`	varchar(255)
,	`serviceProviderId`	int(11) NOT NULL
,	`externalId`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_servicePermissions` (
	`id`	int(11) NOT NULL auto_increment
,	`serviceInstanceId`	int(11) NOT NULL
,	`serviceProviderId`	int(11) NOT NULL
,	`permissionCode`	varchar(255)
,	`class`	varchar(255)
,	`status`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_serviceEntryPoints` (
	`id`	int(11) NOT NULL auto_increment
,	`servicePermissionId`	int(11) NOT NULL
,	`externalId`	varchar(255)
,	`label`	varchar(255)
,	`description`	varchar(255)
,	`icon`	varchar(255)
,	`redirectUrl`	varchar(255)
,	`hidden`	int(11) DEFAULT '0'
,	`http`	int(11) DEFAULT '0'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_roleServicePermissions` (
	`id`	int(11) NOT NULL auto_increment
,	`roleId`	int(11) NOT NULL
,	`servicePermissionId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_userServicePermissions` (
	`id`	int(11) NOT NULL auto_increment
,	`userId`	int(11) NOT NULL
,	`servicePermissionId`	int(11) NOT NULL
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_servicePermissionAccounts` (
	`id`	int(11) NOT NULL auto_increment
,	`userId`	int(11) NOT NULL
,	`servicePermissionId`	int(11) NOT NULL
,	`externalId`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `smb_settings` (
	`id`	int(11) NOT NULL auto_increment
,	`name`	varchar(255)
,	`value`	text
,	PRIMARY KEY (`id`)
,	UNIQUE `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('1','locale','en-US');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('3','product-logo','');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('4','product-logo-url','http://www.parallels.com');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('5','mailNonExistPolicy','discard');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('6','mailBounceMessage','This address no longer accepts mail.');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('7','mailForwardAddress','');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('8','mailRedirectIp','');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('9','mailMaxLetterSize','10000');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('10','mailCheckForViruses','false');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('11','mailWebmail','');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('24','automaticUpdates','true');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('25','spamAction','text');
REPLACE INTO `smb_settings` (`id`,`name`,`value`) VALUES ('26','spamActionText','***SPAM***');

CREATE TABLE IF NOT EXISTS `webalizer_group_referrer` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL
,	`group_name`	varchar(255) NOT NULL
,	`referrer`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `webalizer_hidden_referrer` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`dom_id`	int(10) unsigned NOT NULL
,	`referrer`	varchar(255) NOT NULL
,	PRIMARY KEY (`id`)
,	INDEX `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `Webmails` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`product_id`	varchar(255) NOT NULL
,	`name`	varchar(255) NOT NULL
,	`version`	varchar(255) NOT NULL
,	`release`	varchar(255) NOT NULL
,	`docroot`	varchar(255) NOT NULL
,	`enabled`	enum('false','true') NOT NULL DEFAULT 'false'
,	`serviceNodeId`	int(10) unsigned NOT NULL DEFAULT '1'
,	PRIMARY KEY (`id`)
,	UNIQUE `product_id` (`product_id`)
,	UNIQUE `docroot` (`docroot`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `WebServerSettings` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `WebServerSettingsParameters` (
	`webServerSettingsId`	int(10) unsigned NOT NULL
,	`name`	varchar(255) NOT NULL
,	`value`	text
,	PRIMARY KEY (`webServerSettingsId`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BlUpgrades` (
	`id`	varchar(255) NOT NULL
,	`status`	enum('new','fatal','optional','success') NOT NULL DEFAULT 'new'
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `BlUpgradeActions` (
	`id`	int(10) unsigned NOT NULL auto_increment
,	`action`	varchar(255) NOT NULL
,	`status`	enum('new','error','skip','success') NOT NULL DEFAULT 'new'
,	`message`	varchar(255)
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `WebsitesDiagnostic` (
	`date`	timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
,	`id`	int(10) unsigned NOT NULL auto_increment
,	`type`	enum('regular','manual') NOT NULL DEFAULT 'regular'
,	`depth`	int(11) unsigned NOT NULL DEFAULT '0'
,	`duration`	int(11) unsigned NOT NULL DEFAULT '0'
,	`problems`	mediumblob
,	PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `WebsitesDiagnosticDomains` (
	`websitesDiagnosticId`	int(10) unsigned NOT NULL
,	`domainId`	int(10) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


COMMIT;
